==> beast-trans-api-2.3.7-20250311.092128-9-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiProductVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.thebeastshop.common.BaseDO;

import java.math.BigDecimal;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:18
 */
public class TsOrderAiProductVO extends BaseDO {

    /**
     * 商品code
     */
    private String productCode;

    /**
     * 商品名称
     */
    private String productName;

    /**
     * 数量
     */
    private int quantity;

    /**
     * 品类
     */
    private String category;

    /**
     * 是否预售
     */
    private boolean isPreSale;

    /**
     * 是否赠品
     */
    private boolean isGift;

    /**
     * 实付金额
     */
    private BigDecimal actualPayAmount;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public boolean isPreSale() {
        return isPreSale;
    }

    public void setPreSale(boolean preSale) {
        isPreSale = preSale;
    }

    public boolean isGift() {
        return isGift;
    }

    public void setGift(boolean gift) {
        isGift = gift;
    }

    public BigDecimal getActualPayAmount() {
        return actualPayAmount;
    }

    public void setActualPayAmount(BigDecimal actualPayAmount) {
        this.actualPayAmount = actualPayAmount;
    }

}

==> beast-trans-api-2.3.7-20250312.023305-23-sources.jar: com/thebeastshop/trans/vo/order/ai/TsOrderAiProductVO.java <==
package com.thebeastshop.trans.vo.order.ai;

import com.thebeastshop.common.BaseDO;

import java.math.BigDecimal;

/**
 * @author xiang.gao
 * @date 2025/3/10 19:18
 */
public class TsOrderAiProductVO extends BaseDO {

    /**
     * 商品code
     */
    private String productCode;

    /**
     * 商品名称
     */
    private String productName;

    /**
     * 数量
     */
    private int quantity;

    /**
     * 品类
     */
    private String category;

    /**
     * 是否预售
     */
    private String isPreSale;

    /**
     * 是否赠品
     */
    private String isGift;

    /**
     * 实付金额
     */
    private BigDecimal actualPayAmount;

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public String getCategory() {
        return category;
    }

    public void setCategory(String category) {
        this.category = category;
    }

    public String getIsPreSale() {
        return isPreSale;
    }

    public void setIsPreSale(String isPreSale) {
        this.isPreSale = isPreSale;
    }

    public String getIsGift() {
        return isGift;
    }

    public void setIsGift(String isGift) {
        this.isGift = isGift;
    }

    public BigDecimal getActualPayAmount() {
        return actualPayAmount;
    }

    public void setActualPayAmount(BigDecimal actualPayAmount) {
        this.actualPayAmount = actualPayAmount;
    }

}
